@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--enable-shared' '--disable-install-doc' '--disable-install-rdoc' '--prefix=/opt/puppetlabs/puppet' '--with-opt-dir=/opt/puppetlabs/puppet' 'CFLAGS=-fstack-protector-strong -fno-plt -O2 -Wno-error=implicit-function-declaration' 'LDFLAGS=-L/opt/puppetlabs/puppet/lib -Wl,-rpath=/opt/puppetlabs/puppet/lib,-z,relro,-z,now' 'CPPFLAGS=-I/opt/puppetlabs/puppet/include -D_FORTIFY_SOURCE=2' '--with-baseruby=no' '--enable-dtrace'"
+  CONFIG["configure_args"] = " '--enable-shared' '--disable-install-doc' '--disable-install-rdoc' '--prefix=/opt/puppetlabs/puppet' '--with-opt-dir=/opt/puppetlabs/puppet' 'CFLAGS=-fstack-protector-strong -fno-plt -O2' 'LDFLAGS=-L/opt/puppetlabs/puppet/lib -Wl,-rpath=/opt/puppetlabs/puppet/lib,-z,relro,-z,now' 'CPPFLAGS=-I/opt/puppetlabs/puppet/include -D_FORTIFY_SOURCE=2' '--with-baseruby=no' '--enable-dtrace'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -140,6 +140,8 @@ module RbConfig
   CONFIG["ARCH_FLAG"] = ""
   CONFIG["DLDFLAGS"] = "-L/opt/puppetlabs/puppet/lib -Wl,-rpath=/opt/puppetlabs/puppet/lib,-z,relro,-z,now -Wl,--compress-debug-sections=zlib -L/opt/puppetlabs/puppet/lib  -Wl,-rpath,/opt/puppetlabs/puppet/lib"
   CONFIG["ALLOCA"] = ""
+  CONFIG["EGREP"] = "/usr/bin/grep -E"
+  CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["dsymutil"] = ""
   CONFIG["codesign"] = ""
   CONFIG["cleanlibs"] = ""
@@ -167,7 +169,7 @@ module RbConfig
   CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "gcc (Ubuntu 14.2.0-19ubuntu2) 14.2.0\nCopyright (C) 2024 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "gcc (Ubuntu 11.4.0-1ubuntu1~22.04.2) 11.4.0\nCopyright (C) 2021 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["MJIT_CC"] = "/usr/bin/gcc"
   CONFIG["CSRCFLAG"] = ""
@@ -181,7 +183,7 @@ module RbConfig
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-I/opt/puppetlabs/puppet/include -D_FORTIFY_SOURCE=2 $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -L/opt/puppetlabs/puppet/lib -Wl,-rpath=/opt/puppetlabs/puppet/lib,-z,relro,-z,now -fstack-protector-strong -L/opt/puppetlabs/puppet/lib  -Wl,-rpath,/opt/puppetlabs/puppet/lib -rdynamic -Wl,-export-dynamic -Wl,--no-as-needed"
-  CONFIG["CFLAGS"] = "-fstack-protector-strong -fno-plt -O2 -Wno-error=implicit-function-declaration -fPIC"
+  CONFIG["CFLAGS"] = "-fstack-protector-strong -fno-plt -O2 -fPIC"
   CONFIG["STRIP"] = "strip -S -x"
   CONFIG["RANLIB"] = "gcc-ranlib"
   CONFIG["OBJDUMP"] = "objdump"
